@@ -1,10 +1,9 @@
-set rcsId {$Id: pielabel.tcl,v 1.18 1995/10/14 17:13:32 jfontain Exp $}
+set rcsId {$Id: pielabel.tcl,v 1.22 1995/11/04 17:44:33 jfontain Exp $}
 
-virtual proc pieLabeller::pieLabeller {this canvas args} {
-    global pieLabeller
-
-    # set options default then parse switched options
+proc pieLabeller::pieLabeller {this canvas args} {
+    # set options default
     array set option {-offset 5}
+    # override with user options
     array set option $args
 
     # convert offset to pixel
@@ -13,11 +12,9 @@ virtual proc pieLabeller::pieLabeller {this canvas args} {
     set pieLabeller($this,canvas) $canvas
 }
 
-virtual proc pieLabeller::~pieLabeller {this}
+proc pieLabeller::~pieLabeller {this} {}
 
 proc pieLabeller::bind {this pieId} {
-    global pieLabeller
-
     set pieLabeller($this,pieId) $pieId
 }
 
